# Man config

> config <parameter> <new-value> - In shell mode, set a configuration parameter.
In shell mode you need to set the tunning parameters such as temperature  using the config command.
Passing config without parameters will show the list of parameters you can set with this command.

## Usage

`config`

`config temperature 0.5`